8140687: Move @Contended to the jdk.internal.vm.annotation package
authorchegar
Tue, 24 Nov 2015 11:50:20 +0000
changeset 34369 b6df4cc80001
parent 34368 37b532f4f3b5
child 34371 cc29db9f73d8
8140687: Move @Contended to the jdk.internal.vm.annotation package Reviewed-by: alanb, dholmes, psandoz, shade
jdk/src/java.base/share/classes/java/lang/Thread.java
jdk/src/java.base/share/classes/java/util/concurrent/ConcurrentHashMap.java
jdk/src/java.base/share/classes/java/util/concurrent/Exchanger.java
jdk/src/java.base/share/classes/java/util/concurrent/ForkJoinPool.java
jdk/src/java.base/share/classes/java/util/concurrent/SubmissionPublisher.java
jdk/src/java.base/share/classes/java/util/concurrent/atomic/Striped64.java
jdk/src/java.base/share/classes/jdk/internal/vm/annotation/Contended.java
jdk/src/java.base/share/classes/sun/misc/Contended.java
--- a/jdk/src/java.base/share/classes/java/lang/Thread.java	Tue Nov 24 04:46:04 2015 +0000
+++ b/jdk/src/java.base/share/classes/java/lang/Thread.java	Tue Nov 24 11:50:20 2015 +0000
@@ -2026,15 +2026,15 @@
     // Hence, the fields are isolated with @Contended.
 
     /** The current seed for a ThreadLocalRandom */
-    @sun.misc.Contended("tlr")
+    @jdk.internal.vm.annotation.Contended("tlr")
     long threadLocalRandomSeed;
 
     /** Probe hash value; nonzero if threadLocalRandomSeed initialized */
-    @sun.misc.Contended("tlr")
+    @jdk.internal.vm.annotation.Contended("tlr")
     int threadLocalRandomProbe;
 
     /** Secondary seed isolated from public ThreadLocalRandom sequence */
-    @sun.misc.Contended("tlr")
+    @jdk.internal.vm.annotation.Contended("tlr")
     int threadLocalRandomSecondarySeed;
 
     /* Some private helper methods */
--- a/jdk/src/java.base/share/classes/java/util/concurrent/ConcurrentHashMap.java	Tue Nov 24 04:46:04 2015 +0000
+++ b/jdk/src/java.base/share/classes/java/util/concurrent/ConcurrentHashMap.java	Tue Nov 24 11:50:20 2015 +0000
@@ -2550,7 +2550,7 @@
      * A padded cell for distributing counts.  Adapted from LongAdder
      * and Striped64.  See their internal docs for explanation.
      */
-    @sun.misc.Contended static final class CounterCell {
+    @jdk.internal.vm.annotation.Contended static final class CounterCell {
         volatile long value;
         CounterCell(long x) { value = x; }
     }
--- a/jdk/src/java.base/share/classes/java/util/concurrent/ForkJoinPool.java	Tue Nov 24 04:46:04 2015 +0000
+++ b/jdk/src/java.base/share/classes/java/util/concurrent/ForkJoinPool.java	Tue Nov 24 11:50:20 2015 +0000
@@ -162,7 +162,7 @@
  * @since 1.7
  * @author Doug Lea
  */
-@sun.misc.Contended
+@jdk.internal.vm.annotation.Contended
 public class ForkJoinPool extends AbstractExecutorService {
 
     /*
@@ -780,7 +780,7 @@
      * arrays sharing cache lines. The @Contended annotation alerts
      * JVMs to try to keep instances apart.
      */
-    @sun.misc.Contended
+    @jdk.internal.vm.annotation.Contended
     static final class WorkQueue {
 
         /**
@@ -818,7 +818,7 @@
         final ForkJoinWorkerThread owner; // owning thread or null if shared
         volatile Thread parker;    // == owner during call to park; else null
         volatile ForkJoinTask<?> currentJoin;  // task being joined in awaitJoin
-        @sun.misc.Contended("group2") // separate from other fields
+        @jdk.internal.vm.annotation.Contended("group2") // separate from other fields
         volatile ForkJoinTask<?> currentSteal; // nonnull when running some task
 
         WorkQueue(ForkJoinPool pool, ForkJoinWorkerThread owner) {
--- a/jdk/src/java.base/share/classes/java/util/concurrent/SubmissionPublisher.java	Tue Nov 24 04:46:04 2015 +0000
+++ b/jdk/src/java.base/share/classes/java/util/concurrent/SubmissionPublisher.java	Tue Nov 24 11:50:20 2015 +0000
@@ -975,7 +975,7 @@
      * than users expect.
      */
     @SuppressWarnings("serial")
-    @sun.misc.Contended
+    @jdk.internal.vm.annotation.Contended
     private static final class BufferedSubscription<T>
         implements Flow.Subscription, ForkJoinPool.ManagedBlocker {
         // Order-sensitive field declarations
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/jdk/src/java.base/share/classes/jdk/internal/vm/annotation/Contended.java	Tue Nov 24 11:50:20 2015 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
+ * particular file as subject to the "Classpath" exception as provided
+ * by Oracle in the LICENSE file that accompanied this code.
+ *
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
+ *
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
+ */
+
+package jdk.internal.vm.annotation;
+
+import java.lang.annotation.ElementType;
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.Target;
+
+/**
+ * <p>An annotation expressing that objects and/or their fields are
+ * expected to encounter memory contention, generally in the form of
+ * "false sharing". This annotation serves as a hint that such objects
+ * and fields should reside in locations isolated from those of other
+ * objects or fields. Susceptibility to memory contention is a
+ * property of the intended usages of objects and fields, not their
+ * types or qualifiers. The effects of this annotation will nearly
+ * always add significant space overhead to objects. The use of
+ * {@code @Contended} is warranted only when the performance impact of
+ * this time/space tradeoff is intrinsically worthwhile; for example,
+ * in concurrent contexts in which each instance of the annotated
+ * class is often accessed by a different thread.
+ *
+ * <p>A {@code @Contended} field annotation may optionally include a
+ * <i>contention group</i> tag. A contention group defines a set of one
+ * or more fields that collectively must be isolated from all other
+ * contention groups. The fields in the same contention group may not be
+ * pairwise isolated. With no contention group tag (or with the default
+ * empty tag: "") each {@code @Contended} field resides in its own
+ * <i>distinct</i> and <i>anonymous</i> contention group.
+ *
+ * <p>When the annotation is used at the class level, the effect is
+ * equivalent to grouping all the declared fields not already having the
+ * {@code @Contended} annotation into the same anonymous group.
+ * With the class level annotation, implementations may choose different
+ * isolation techniques, such as isolating the entire object, rather than
+ * isolating distinct fields. A contention group tag has no meaning
+ * in a class level {@code @Contended} annotation, and is ignored.
+ *
+ * <p>The class level {@code @Contended} annotation is not inherited and has
+ * no effect on the fields declared in any sub-classes. The effects of all
+ * {@code @Contended} annotations, however, remain in force for all
+ * subclass instances, providing isolation of all the defined contention
+ * groups. Contention group tags are not inherited, and the same tag used
+ * in a superclass and subclass, represent distinct contention groups.
+ *
+ * @since 1.8
+ */
+@Retention(RetentionPolicy.RUNTIME)
+@Target({ElementType.FIELD, ElementType.TYPE})
+public @interface Contended {
+
+    /**
+     * The (optional) contention group tag.
+     * This tag is only meaningful for field level annotations.
+     *
+     * @return contention group tag.
+     */
+    String value() default "";
+}
--- a/jdk/src/java.base/share/classes/sun/misc/Contended.java	Tue Nov 24 04:46:04 2015 +0000
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * This code is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.  Oracle designates this
- * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the LICENSE file that accompanied this code.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * version 2 for more details (a copy is included in the LICENSE file that
- * accompanied this code).
- *
- * You should have received a copy of the GNU General Public License version
- * 2 along with this work; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
- * or visit www.oracle.com if you need additional information or have any
- * questions.
- */
-
-package sun.misc;
-
-import java.lang.annotation.ElementType;
-import java.lang.annotation.Retention;
-import java.lang.annotation.RetentionPolicy;
-import java.lang.annotation.Target;
-
-/**
- * <p>An annotation expressing that objects and/or their fields are
- * expected to encounter memory contention, generally in the form of
- * "false sharing". This annotation serves as a hint that such objects
- * and fields should reside in locations isolated from those of other
- * objects or fields. Susceptibility to memory contention is a
- * property of the intended usages of objects and fields, not their
- * types or qualifiers. The effects of this annotation will nearly
- * always add significant space overhead to objects. The use of
- * {@code @Contended} is warranted only when the performance impact of
- * this time/space tradeoff is intrinsically worthwhile; for example,
- * in concurrent contexts in which each instance of the annotated
- * class is often accessed by a different thread.
- *
- * <p>A {@code @Contended} field annotation may optionally include a
- * <i>contention group</i> tag. A contention group defines a set of one
- * or more fields that collectively must be isolated from all other
- * contention groups. The fields in the same contention group may not be
- * pairwise isolated. With no contention group tag (or with the default
- * empty tag: "") each {@code @Contended} field resides in its own
- * <i>distinct</i> and <i>anonymous</i> contention group.
- *
- * <p>When the annotation is used at the class level, the effect is
- * equivalent to grouping all the declared fields not already having the
- * {@code @Contended} annotation into the same anonymous group.
- * With the class level annotation, implementations may choose different
- * isolation techniques, such as isolating the entire object, rather than
- * isolating distinct fields. A contention group tag has no meaning
- * in a class level {@code @Contended} annotation, and is ignored.
- *
- * <p>The class level {@code @Contended} annotation is not inherited and has
- * no effect on the fields declared in any sub-classes. The effects of all
- * {@code @Contended} annotations, however, remain in force for all
- * subclass instances, providing isolation of all the defined contention
- * groups. Contention group tags are not inherited, and the same tag used
- * in a superclass and subclass, represent distinct contention groups.
- *
- * @since 1.8
- */
-@Retention(RetentionPolicy.RUNTIME)
-@Target({ElementType.FIELD, ElementType.TYPE})
-public @interface Contended {
-
-    /**
-     * The (optional) contention group tag.
-     * This tag is only meaningful for field level annotations.
-     *
-     * @return contention group tag.
-     */
-    String value() default "";
-}
--- a/jdk/src/java.base/share/classes/java/util/concurrent/Exchanger.java	Tue Nov 24 04:46:04 2015 +0000
+++ b/jdk/src/java.base/share/classes/java/util/concurrent/Exchanger.java	Tue Nov 24 11:50:20 2015 +0000
@@ -155,7 +155,7 @@
      * a value that is enough for common platforms.  Additionally,
      * extra care elsewhere is taken to avoid other false/unintended
      * sharing and to enhance locality, including adding padding (via
      * sun.misc.Contended) to Nodes, embedding "bound" as an Exchanger
      * field, and reworking some park/unpark mechanics compared to
      * LockSupport versions.
      *
@@ -304,10 +304,10 @@
 
     /**
      * Nodes hold partially exchanged data, plus other per-thread
      * bookkeeping. Padded via @sun.misc.Contended to reduce memory
      * contention.
      */
-    @sun.misc.Contended static final class Node {
+    @jdk.internal.vm.annotation.Contended static final class Node {
         int index;              // Arena index
         int bound;              // Last recorded value of Exchanger.bound
         int collides;           // Number of CAS failures at current bound
@@ -155,7 +155,7 @@
      * extra care elsewhere is taken to avoid other false/unintended
      * sharing and to enhance locality, including adding padding (via
-     * sun.misc.Contended) to Nodes, embedding "bound" as an Exchanger
+     * jdk.internal.vm.annotation.Contended) to Nodes, embedding "bound" as an Exchanger
      * field, and reworking some park/unpark mechanics compared to
      * LockSupport versions.
@@ -304,10 +304,10 @@
     /**
      * Nodes hold partially exchanged data, plus other per-thread
-     * bookkeeping. Padded via @sun.misc.Contended to reduce memory
+     * bookkeeping. Padded via @jdk.internal.vm.annotation.Contended to reduce memory
      * contention.
      */
--- a/jdk/src/java.base/share/classes/java/util/concurrent/atomic/Striped64.java	Tue Nov 24 04:46:04 2015 +0000
+++ b/jdk/src/java.base/share/classes/java/util/concurrent/atomic/Striped64.java	Tue Nov 24 11:50:20 2015 +0000
@@ -55,7 +55,7 @@
      * accessed directly by subclasses.
      *
      * Table entries are of class Cell; a variant of AtomicLong padded
      * (via @sun.misc.Contended) to reduce cache contention. Padding
      * is overkill for most Atomics because they are usually
      * irregularly scattered in memory and thus don't interfere much
      * with each other. But Atomic objects residing in arrays will
@@ -119,7 +119,7 @@
      * JVM intrinsics note: It would be possible to use a release-only
      * form of CAS here, if it were provided.
      */
-    @sun.misc.Contended static final class Cell {
+    @jdk.internal.vm.annotation.Contended static final class Cell {
         volatile long value;
         Cell(long x) { value = x; }
         final boolean cas(long cmp, long val) {
@@ -55,7 +55,7 @@
      *
      * Table entries are of class Cell; a variant of AtomicLong padded
-     * (via @sun.misc.Contended) to reduce cache contention. Padding
+     * (via @jdk.internal.vm.annotation.Contended) to reduce cache contention. Padding
      * is overkill for most Atomics because they are usually
      * irregularly scattered in memory and thus don't interfere much